@@ -18,7 +18,7 @@ from django_mailbox.transports import Pop3Transport, ImapTransport,\
     MMDFTransport
 from django_mailbox.signals import message_received
 import six
-from six.moves.urllib.parse import unquote, urlparse
+from six.moves.urllib.parse import parse_qs, unquote, urlparse
 
 from .utils import convert_header_to_unicode
 
@@ -115,6 +115,10 @@ class Mailbox(models.Model):
     def _protocol_info(self):
         return urlparse(self.uri)
 
+    @property
+    def _query_string(self):
+        return parse_qs(self._protocol_info.query)
+
     @property
     def _domain(self):
         return self._protocol_info.hostname
@@ -146,6 +150,13 @@ class Mailbox(models.Model):
     def use_ssl(self):
         return '+ssl' in self._protocol_info.scheme.lower()
 
+    @property
+    def archive(self):
+        archive_folder = self._query_string.get('archive', None)
+        if not archive_folder:
+            return None
+        return archive_folder[0]
+
     def get_connection(self):
         if not self.uri:
             return None
@@ -153,7 +164,8 @@ class Mailbox(models.Model):
             conn = ImapTransport(
                 self.location,
                 port=self.port if self.port else None,
-                ssl=self.use_ssl
+                ssl=self.use_ssl,
+                archive=self.archive
             )
             conn.connect(self.username, self.password)
         elif self.type == 'pop3':
